@@ -305,14 +305,7 @@ call_event(VALUE trace_point, void *data)
 
   CALL_EVENT_SETUP;
 
-  /* nil method_id means we are at top level so there can't be a method
-   * breakpoint here. Just leave then. */
   msym = rb_tracearg_method_id(trace_arg);
-  if (NIL_P(msym))
-  {
-    EVENT_TEARDOWN;
-    return;
-  }
 
   mid = SYM2ID(msym);
   klass = rb_tracearg_defined_class(trace_arg);
@@ -367,7 +360,9 @@ return_event(VALUE trace_point, void *data)
      *   [#7] b_return@/hort/core_ext/numeric/conversions.rb:133 BigDecimal#to_s
      *  [#7] return@:0 Fixnum#to_s # => This guy...
      */
-    if (!NIL_P(file))
+    if (NIL_P(file))
+      rb_warn("The TracePoint API emitted a return event without file information. It might be a bug, please report this.");
+    else
     {
       line = rb_tracearg_lineno(trace_arg);
       binding = rb_tracearg_binding(trace_arg);
@@ -436,7 +431,7 @@ raise_event(VALUE trace_point, void *data)
 
   raised_exception = rb_tracearg_raised_exception(trace_arg);
 
-  if (post_mortem == Qtrue)
+  if (post_mortem == Qtrue && !rb_ivar_defined(raised_exception, rb_intern("@__bb_context")))
   {
     pm_context = context_dup(dc);
     rb_ivar_set(raised_exception, rb_intern("@__bb_context"), pm_context);
