@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "simplecov" if ENV["NOCOV"].nil?
+require "support/simplecov"
 require "support/test_case"
 
 Byebug::TestCase.before_suite
